Mu's Developers
===============

Mu was created and `mostly written by <https://github.com/mu-editor/mu/graphs/contributors>`_
Nicholas H.Tollervey (ntoll@ntoll.org). Some of Nicholas's work has been
`magnificently supported <http://ntoll.org/article/mu-pi>`_ by the
`Raspberry Pi Foundation <http://raspberrypi.org/>`_.

Happily, many people have volunteered wonderful and varied contributions to Mu.
These include (but are not limited to):

* Tim Golden (mail@timgolden.me.uk)
* Peter Inglesby
* Carlos Pereira Atencio (carlosperate@embeddedlog.com)
* Nick Sarbicki (nick.a.sarbicki@gmail.com)
* Kushal Das (mail@kushaldas.in)
* Tibs / Tony Ibbs (tibs@tonyibbs.co.uk)
* Zander Brown
* Alistair Broomhead (alistair.broomhead@gmail.com)
* Frank Morton (fmorton@mac.com)

We welcome contributions from anyone! Please see :doc:`contributing` for more
information.

If you have made a contribution to Mu and would like to be recognised, please
feel to add yourself to the list above.
